@@ -33,7 +33,7 @@ import zipfile
 
 from distutils.version import LooseVersion
 
-__version__ = "0.20.5"
+__version__ = "0.21.0"
 
 is_windows = os.name == "nt"
 
@@ -127,7 +127,7 @@ https://semver.org/ for more information."""
         "homepage": ask("Homepage URL ({})", "https://example.com/"),
         "type_id": ask(
             "Target type ({})".format(
-                " or ".join(map(lambda t: type_map[t], lang.types))
+                " or ".join([type_map[t] for t in lang.types])
             ),
             cli_args.type_id or "e",
             mapper=lambda v: v[0:1].lower(),
@@ -139,7 +139,7 @@ explicitly mark symbols for export/import, but only when built as a shared
 library."""
         ),
         "std": ask(
-            f"{lang} standard ({lang.options})",
+            "{} standard ({})".format(lang, "/".join(lang.options)),
             cli_args.std or lang.default,
             predicate=lambda v: v in lang.options,
             header=f"{lang} standard to use. Defaults to {lang.default}.",
@@ -459,7 +459,7 @@ pass as the first flag to make a vcpkg port of <name> with type -s or -h",
             help=help,
         )
     defaults = ", ".join(
-        map(lambda lang: f"{lang} - {lang.default}", [cpp_lang, c_lang])
+        [f"{lang} - {lang.default}" for lang in [cpp_lang, c_lang]]
     )
     p.add_argument(
         "--std",
